changeset 7055:0f4564b4cc2c

convert: improve convert_source documentation
author Patrick Mezard <pmezard@gmail.com>
date Mon, 29 Sep 2008 09:30:36 +0200
parents e837f2294643
children 2c1f18b88b6a
files hgext/convert/common.py
diffstat 1 files changed, 11 insertions(+), 5 deletions(-) [+]
line wrap: on
line diff
--- a/hgext/convert/common.py	Sun Sep 28 20:40:38 2008 +0200
+++ b/hgext/convert/common.py	Mon Sep 29 09:30:36 2008 +0200
@@ -68,17 +68,23 @@
         raise NotImplementedError()
 
     def getfile(self, name, rev):
-        """Return file contents as a string"""
+        """Return file contents as a string. rev is the identifier returned
+        by a previous call to getchanges().
+        """
         raise NotImplementedError()
 
     def getmode(self, name, rev):
-        """Return file mode, eg. '', 'x', or 'l'"""
+        """Return file mode, eg. '', 'x', or 'l'. rev is the identifier
+        returned by a previous call to getchanges().
+        """
         raise NotImplementedError()
 
     def getchanges(self, version):
-        """Returns a tuple of (files, copies)
-        Files is a sorted list of (filename, id) tuples for all files changed
-        in version, where id is the source revision id of the file.
+        """Returns a tuple of (files, copies). 
+
+        files is a sorted list of (filename, id) tuples for all files
+        changed between version and it's first parent returned by
+        getcommit(). id is the source revision id of the file.
 
         copies is a dictionary of dest: source
         """